summaryrefslogtreecommitdiffstats
path: root/chrome/browser/sync/sync_setup_wizard.cc
diff options
context:
space:
mode:
Diffstat (limited to 'chrome/browser/sync/sync_setup_wizard.cc')
-rw-r--r--chrome/browser/sync/sync_setup_wizard.cc13
1 files changed, 4 insertions, 9 deletions
diff --git a/chrome/browser/sync/sync_setup_wizard.cc b/chrome/browser/sync/sync_setup_wizard.cc
index 2cb6b7e..632d60d 100644
--- a/chrome/browser/sync/sync_setup_wizard.cc
+++ b/chrome/browser/sync/sync_setup_wizard.cc
@@ -260,19 +260,14 @@ SyncSetupWizard::SyncSetupWizard(ProfileSyncService* service)
: service_(service),
flow_container_(new SyncSetupFlowContainer()),
parent_window_(NULL) {
// If we're in a unit test, we may not have an IO thread. Avoid
// creating a SyncResourcesSource since we may leak it (since it's
// DeleteOnUIThread).
- if (BrowserThread::IsMessageLoopValid(BrowserThread::IO)) {
+ if (BrowserThread::IsMessageLoopValid(BrowserThread::IO) &&
+ service_->profile()) {
// Add our network layer data source for 'cloudy' URLs.
SyncResourcesSource* sync_source = new SyncResourcesSource();
- bool posted =
- BrowserThread::PostTask(
- BrowserThread::IO, FROM_HERE,
- NewRunnableMethod(ChromeURLDataManager::GetInstance(),
- &ChromeURLDataManager::AddDataSource,
- make_scoped_refptr(sync_source)));
- DCHECK(posted);
+ service_->profile()->GetChromeURLDataManager()->AddDataSource(sync_source);
}
}
@@ -260,19 +260,14 @@ SyncSetupWizard::SyncSetupWizard(ProfileSyncService* service)
flow_container_(new SyncSetupFlowContainer()),
parent_window_(NULL) {
- // If we're in a unit test, we may not have an IO thread. Avoid
+ // If we're in a unit test, we may not have an IO thread or profile. Avoid
// creating a SyncResourcesSource since we may leak it (since it's
// DeleteOnUIThread).